@@ -1,16 +1,16 @@
 /*
     Copyright 2012 Viranch Mehta <viranch.mehta@gmail.com>
-  
+
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
     the Free Software Foundation, either version 2 of the License, or
     (at your option) any later version.
-   
+
     This program is distributed in the hope that it will be useful,
     but WITHOUT ANY WARRANTY; without even the implied warranty of
     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
     GNU General Public License for more details.
-   
+
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
@@ -23,8 +23,9 @@
 #include <QAction>
 #include <QKeyEvent>
 #include <QCursor>
+#include <QStandardPaths>
+#include <QQuickItem>
 
-#include <KStandardDirs>
 #include <KgThemeProvider>
 
 CanvasWidget::CanvasWidget(QWidget *parent) :
@@ -32,8 +33,8 @@ CanvasWidget::CanvasWidget(QWidget *parent) :
     m_provider(new KgThemeProvider)
 {
     m_provider->discoverThemes("appdata", QLatin1String("themes"));
-    m_provider->setDeclarativeEngine("themeProvider", engine());
-    QString path = KStandardDirs::locate("appdata", "qml/main.qml");
+    m_provider->setDeclarativeEngine(QLatin1Literal("themeProvider"), engine());
+    QString path = QStandardPaths::locate(QStandardPaths::DataLocation, QLatin1Literal("qml/main.qml"));
     setSource(QUrl::fromLocalFile(path));
 
     // forward signals from QML
@@ -43,7 +44,7 @@ CanvasWidget::CanvasWidget(QWidget *parent) :
 
     // for handling mouse cursor
     connect(rootObject(), SIGNAL(pausedChanged()), this, SLOT(updateCursor()));
-    connect(this, SIGNAL(gameEnded(int,int,int)), this, SLOT(resetCursor()));
+    connect(this, &CanvasWidget::gameEnded, this, &CanvasWidget::resetCursor);
 }
 
 CanvasWidget::~CanvasWidget()
@@ -53,14 +54,14 @@ CanvasWidget::~CanvasWidget()
 
 void CanvasWidget::updateFireShortcut()
 {
-    QAction *fireAction = qobject_cast<QAction*>(sender());
+    QAction *fireAction = qobject_cast<QAction *>(sender());
     QString shortcut = fireAction->shortcut().toString(QKeySequence::NativeText);
     rootObject()->setProperty("fireShortcut", shortcut);
 }
 
 void CanvasWidget::resizeEvent(QResizeEvent *event)
 {
-    QDeclarativeView::resizeEvent(event);
+    QQuickWidget::resizeEvent(event);
     QMetaObject::invokeMethod(rootObject(), "updateGeometry");
 }
 
@@ -140,7 +141,7 @@ void CanvasWidget::resetMousePosition()
 void CanvasWidget::keyPressEvent(QKeyEvent *event)
 {
     if (event->isAutoRepeat()) {
-        QDeclarativeView::keyPressEvent(event);
+        QQuickWidget::keyPressEvent(event);
         return;
     }
     int key = event->key();
@@ -154,7 +155,7 @@ void CanvasWidget::keyPressEvent(QKeyEvent *event)
         m_barDirection = -1;
         break;
     default:
-        QDeclarativeView::keyPressEvent(event);
+        QQuickWidget::keyPressEvent(event);
         return;
     }
 
@@ -164,7 +165,7 @@ void CanvasWidget::keyPressEvent(QKeyEvent *event)
 void CanvasWidget::keyReleaseEvent(QKeyEvent *event)
 {
     if (event->isAutoRepeat()) {
-        QDeclarativeView::keyReleaseEvent(event);
+        QQuickWidget::keyReleaseEvent(event);
         return;
     }
     int key = event->key();
@@ -176,7 +177,7 @@ void CanvasWidget::keyReleaseEvent(QKeyEvent *event)
         m_leftPressed = false;
         break;
     default:
-        QDeclarativeView::keyReleaseEvent(event);
+        QQuickWidget::keyReleaseEvent(event);
         return;
     }
 
@@ -194,5 +195,5 @@ void CanvasWidget::keyReleaseEvent(QKeyEvent *event)
 void CanvasWidget::focusOutEvent(QFocusEvent *event)
 {
     emit focusLost();
-    QDeclarativeView::focusOutEvent(event);
+    QQuickWidget::focusOutEvent(event);
 }
